@@ -433,7 +433,15 @@ FDMKERNEL <- function(lppobj, dtt, dtx, M, nsave=1,
   blocklength <- blockend - blockstart + 1L
   elapsedtime <- blockend * dtt
 
-  if(verbose) cat("Running iterative solver ..")
+  if(verbose) {
+    #' estimate run time for iterative solver
+    tstart <- proc.time()
+    niets <- A %*% U0
+    tend <- proc.time()
+    dura <- M * (tend-tstart)
+    splat("Starting iterative solver. Estimated duration", codetime(dura))
+    cat("Running iterative solver ..")
+  }
   
   U <- matrix(0, nvert, nsave)
 
@@ -683,7 +691,7 @@ resolve.heat.steps <-
   #' ------------- SPACING OF SAMPLE POINTS, dx ---------------
   if(dx.given) {
     if(verbose) splat(" Validating dx =", dx)
-    check.finite(dx)
+    check.finite(dx, xname="dx")
     stopifnot(dx > 0)
     if(finespacing && dx > lmin/3)
       stop(paste("dx must not exceed (shortest nonzero edge length)/3 =",
